==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/oc.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Lo partiment de servidor a servidor es pas activat sus aqueste servidor",
    "The mountpoint name contains invalid characters." : "Lo nom del punt de montatge conten de caractèrs invalids.",
    "Invalid or untrusted SSL certificate" : "Certificat SSL invalid o pas fisable",
    "Could not authenticate to remote share, password might be wrong" : "Impossible de s'autentificar al partiment distant : lo senhal es probablament incorrècte",
    "Storage not valid" : "Supòrt d'emmagazinatge invalid",
    "Couldn't add remote share" : "Impossible d'apondre lo partiment distant",
    "Shared with you" : "Partejats amb vos",
    "Shared with others" : "Partejats amb d'autres",
    "Shared by link" : "Partejats per ligam",
    "Nothing shared with you yet" : "Cap de fichièr es pas partejat amb vos pel moment",
    "Files and folders others share with you will show up here" : "Los fichièrs e dorsièrs partejats amb vos apareisseràn aicí",
    "Nothing shared yet" : "Res es pas partejat pel moment",
    "Files and folders you share will show up here" : "Los fichièrs e dorsièrs que partejatz apareisseràn aicí",
    "No shared links" : "Pas cap de partiment per ligam",
    "Files and folders you share by link will show up here" : "Los fichièrs e dorsièrs que partejatz per ligam apareisseràn aicí",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Volètz apondre lo partiment distant {name} de {owner}@{remote} ?",
    "Remote share" : "Partiment distant",
    "Remote share password" : "Senhal del partiment distant",
    "Cancel" : "Anullar",
    "Add remote share" : "Apondre un partiment distant",
    "You can upload into this folder" : "Podètz mandar dins aqueste dorsièr",
    "No ownCloud installation (7 or higher) found at {remote}" : "Cap d'installacion ownCloud (7 o superior) pas trobada sus {remote}",
    "Invalid ownCloud url" : "URL ownCloud invalida",
    "Shared by" : "Partejat per",
    "Sharing" : "Partiment",
    "A file or folder has been <strong>shared</strong>" : "Un fichièr o un repertòri es estat <strong>partejat</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Un fichièr o un repertòri es estat partejat depuis <strong>un autre servidor</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Un fichièr o un repertòri partejat publicament es estat <strong>telecargat</strong>",
    "You received a new remote share %2$s from %1$s" : "L'utilizaire %1$s a partejat la ressorsa distanta %2$s amb vos",
    "You received a new remote share from %s" : "Avètz recebut un partiment distant de %s",
    "%1$s accepted remote share %2$s" : "%1$s a acceptat lo partiment distant %2$s",
    "%1$s declined remote share %2$s" : "%1$s a refusat lo partiment distant %2$s",
    "%1$s unshared %2$s from you" : "%1$s a daissat de partejar %2$s amb vos",
    "Public shared folder %1$s was downloaded" : "Lo dorsièr public %1$s es estat telecargat",
    "Public shared file %1$s was downloaded" : "Lo fichièr public %1$s es estat telecargat",
    "You shared %1$s with %2$s" : "Avètz partejat %1$s amb %2$s",
    "You shared %1$s with group %2$s" : "Avètz partejat %1$s amb lo grop %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s partejat %1$s amb %3$s",
    "%2$s shared %1$s with group %3$s" : "%2$s partejat %1$s amb lo grop %3$s",
    "%2$s shared %1$s via link" : "%2$s a partejat %1$s per ligam public",
    "%2$s shared %1$s with you" : "%2$s a partejat %1$s amb vos",
    "You shared %1$s via link" : "Avètz partejat %1$s per ligam public",
    "Shares" : "Partiments",
    "You received %2$s as a remote share from %1$s" : "Avètz recebut %2$s en tant que partiment distant per %1$s",
    "Accept" : "Acceptar",
    "Decline" : "Refusar",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Partejatz amb ieu gràcias a mon identificant Federated Cloud #owncloud %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Partejatz amb ieu gràcias a mon identificant Federated Cloud #owncloud",
    "This share is password-protected" : "Aqueste partiment es protegit per un senhal",
    "The password is wrong. Try again." : "Lo senhal es incorrècte. Ensajatz tornamai.",
    "Password" : "Senhal",
    "No entries found in this folder" : "Cap d'entrada pas trobada dins aqueste dorsièr",
    "Name" : "Nom",
    "Share time" : "Data de partiment",
    "Sorry, this link doesn’t seem to work anymore." : "O planhèm, mas sembla qu'aqueste ligam fonciona pas mai.",
    "Reasons might be:" : "Las rasons pòdon èsser :",
    "the item was removed" : "l'element es estat suprimit",
    "the link expired" : "lo ligam a expirat",
    "sharing is disabled" : "lo partiment es desactivat",
    "For more info, please ask the person who sent this link." : "Per mai d'informacions, contactatz la persona qu'a mandat aqueste ligam.",
    "Add to your ownCloud" : "Apondre a vòstre ownCloud",
    "Download" : "Telecargar",
    "Download %s" : "Telecargar %s",
    "Direct link" : "Ligam dirècte",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Open documentation" : "Veire la documentacion",
    "Allow users on this server to send shares to other servers" : "Autorizar los utilizaires d'aqueste servidor a mandar de partiments cap a d'autres servidors",
    "Allow users on this server to receive shares from other servers" : "Autorizar los utilizaires d'aqueste servidor a recebre de partiments d'autres servidors",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Vòstre identificant Federated Cloud :",
    "Share it:" : "Partejar :",
    "Add to your website" : "Apondre a vòstre site web",
    "Share with me via ownCloud" : "Partejatz amb ieu via ownCloud",
    "HTML Code:" : "Còde HTML :"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/oc.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Lo partiment de servidor a servidor es pas activat sus aqueste servidor",
    "The mountpoint name contains invalid characters." : "Lo nom del punt de montatge conten de caractèrs invalids.",
    "Invalid or untrusted SSL certificate" : "Certificat SSL invalid o pas fisable",
    "Could not authenticate to remote share, password might be wrong" : "Impossible de s'autentificar al partiment distant : lo senhal es probablament incorrècte",
    "Storage not valid" : "Supòrt d'emmagazinatge invalid",
    "Couldn't add remote share" : "Impossible d'apondre lo partiment distant",
    "Shared with you" : "Partejats amb vos",
    "Shared with others" : "Partejats amb d'autres",
    "Shared by link" : "Partejats per ligam",
    "Nothing shared with you yet" : "Cap de fichièr es pas partejat amb vos pel moment",
    "Files and folders others share with you will show up here" : "Los fichièrs e dorsièrs partejats amb vos apareisseràn aicí",
    "Nothing shared yet" : "Res es pas partejat pel moment",
    "Files and folders you share will show up here" : "Los fichièrs e dorsièrs que partejatz apareisseràn aicí",
    "No shared links" : "Pas cap de partiment per ligam",
    "Files and folders you share by link will show up here" : "Los fichièrs e dorsièrs que partejatz per ligam apareisseràn aicí",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Volètz apondre lo partiment distant {name} de {owner}@{remote} ?",
    "Remote share" : "Partiment distant",
    "Remote share password" : "Senhal del partiment distant",
    "Cancel" : "Anullar",
    "Add remote share" : "Apondre un partiment distant",
    "You can upload into this folder" : "Podètz mandar dins aqueste dorsièr",
    "No ownCloud installation (7 or higher) found at {remote}" : "Cap d'installacion ownCloud (7 o superior) pas trobada sus {remote}",
    "Invalid ownCloud url" : "URL ownCloud invalida",
    "Shared by" : "Partejat per",
    "Sharing" : "Partiment",
    "A file or folder has been <strong>shared</strong>" : "Un fichièr o un repertòri es estat <strong>partejat</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Un fichièr o un repertòri es estat partejat depuis <strong>un autre servidor</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Un fichièr o un repertòri partejat publicament es estat <strong>telecargat</strong>",
    "You received a new remote share %2$s from %1$s" : "L'utilizaire %1$s a partejat la ressorsa distanta %2$s amb vos",
    "You received a new remote share from %s" : "Avètz recebut un partiment distant de %s",
    "%1$s accepted remote share %2$s" : "%1$s a acceptat lo partiment distant %2$s",
    "%1$s declined remote share %2$s" : "%1$s a refusat lo partiment distant %2$s",
    "%1$s unshared %2$s from you" : "%1$s a daissat de partejar %2$s amb vos",
    "Public shared folder %1$s was downloaded" : "Lo dorsièr public %1$s es estat telecargat",
    "Public shared file %1$s was downloaded" : "Lo fichièr public %1$s es estat telecargat",
    "You shared %1$s with %2$s" : "Avètz partejat %1$s amb %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s partejat %1$s amb %3$s",
    "You shared %1$s with group %2$s" : "Avètz partejat %1$s amb lo grop %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s partejat %1$s amb lo grop %3$s",
    "%2$s shared %1$s via link" : "%2$s a partejat %1$s per ligam public",
    "You shared %1$s via link" : "Avètz partejat %1$s per ligam public",
    "%2$s shared %1$s with you" : "%2$s a partejat %1$s amb vos",
    "Downloaded via public link" : "Telecargat per ligam public",
    "Shared with %2$s" : "Partejat amb %2$s",
    "Shared with %3$s by %2$s" : "Partejat amb %3$s per %2$s",
    "Shared with group %2$s" : "Partejat amb lo grop %2$s",
    "Shared with group %3$s by %2$s" : "Partejat amb lo grop %3$s per %2$s",
    "Shared via link by %2$s" : "Partejat via ligam per %2$s",
    "Shared via public link" : "Partejat per ligam public",
    "Shared by %2$s" : "Partejat per %2$s",
    "Shares" : "Partiments",
    "Accept" : "Acceptar",
    "Decline" : "Refusar",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Partejatz amb ieu gràcias a mon identificant Federated Cloud #owncloud %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Partejatz amb ieu gràcias a mon identificant Federated Cloud #owncloud",
    "This share is password-protected" : "Aqueste partiment es protegit per un senhal",
    "The password is wrong. Try again." : "Lo senhal es incorrècte. Ensajatz tornamai.",
    "Password" : "Senhal",
    "No entries found in this folder" : "Cap d'entrada pas trobada dins aqueste dorsièr",
    "Name" : "Nom",
    "Share time" : "Data de partiment",
    "Sorry, this link doesn’t seem to work anymore." : "O planhèm, mas sembla qu'aqueste ligam fonciona pas mai.",
    "Reasons might be:" : "Las rasons pòdon èsser :",
    "the item was removed" : "l'element es estat suprimit",
    "the link expired" : "lo ligam a expirat",
    "sharing is disabled" : "lo partiment es desactivat",
    "For more info, please ask the person who sent this link." : "Per mai d'informacions, contactatz la persona qu'a mandat aqueste ligam.",
    "Add to your ownCloud" : "Apondre a vòstre ownCloud",
    "Download" : "Telecargar",
    "Download %s" : "Telecargar %s",
    "Direct link" : "Ligam dirècte",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Open documentation" : "Veire la documentacion",
    "Allow users on this server to send shares to other servers" : "Autorizar los utilizaires d'aqueste servidor a mandar de partiments cap a d'autres servidors",
    "Allow users on this server to receive shares from other servers" : "Autorizar los utilizaires d'aqueste servidor a recebre de partiments d'autres servidors",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Vòstre identificant Federated Cloud :",
    "Share it:" : "Partejar :",
    "Add to your website" : "Apondre a vòstre site web",
    "Share with me via ownCloud" : "Partejatz amb ieu via ownCloud",
    "HTML Code:" : "Còde HTML :"
},
"nplurals=2; plural=(n > 1);");
